@@ -117,7 +117,7 @@ class Ui_MainWindow(object):
 
 
     def showPage(self, strpage):
-        myzipfile='/home/user/MyDocs/.documents/.quran/qdata_for_quran1.0.0.qdb'
+        myzipfile='/home/user/MyDocs/.documents/Quran/qdata_for_quran1.0.0.qdb'
         zfile=zipfile.ZipFile(myzipfile, "r")
         p=zfile.read(strpage)
         img=QtGui.QImage()
